@@ -14,9 +14,14 @@ lazy_extractors_filename = sys.argv[1]
 if os.path.exists(lazy_extractors_filename):
     os.remove(lazy_extractors_filename)
 
+# Block plugins from loading
+os.rename('ytdlp_plugins', 'ytdlp_plugins_blocked')
+
 from yt_dlp.extractor import _ALL_CLASSES
 from yt_dlp.extractor.common import InfoExtractor, SearchInfoExtractor
 
+os.rename('ytdlp_plugins_blocked', 'ytdlp_plugins')
+
 with open('devscripts/lazy_load_template.py', 'rt') as f:
     module_template = f.read()
 
