@@ -247,7 +247,7 @@ class NPOIE(NPOBaseIE):
 
         if not formats:
             if not self._downloader.params.get('allow_unplayable_formats') and drm:
-                raise ExtractorError('This video is DRM protected.', expected=True)
+                self.raise_no_formats('This video is DRM protected.', expected=True)
             return
 
         self._sort_formats(formats)
